@@ -47,8 +47,13 @@ def bioshed_init( args ):
 
     """
     system_type = args['system']
+    init_path = args['initpath']
     which_os = ''
 
+    # first create init directory if doesn't exist
+    if not os.path.exists(init_path):
+        os.mkdir(init_path)
+
     if 'ubuntu' in system_type.lower():
         bioshed_init_ubuntu()
         which_os = 'ubuntu'
